/* -*- c++ -*- */
/*
 * Copyright 2008,2009,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_GR_SENNH_BAT_SINK_B_H
#define INCLUDED_GR_SENNH_BAT_SINK_B_H

#include <gnuradio/blocks/api.h>
#include <gnuradio/sync_block.h>

namespace gr {
  namespace blocks {

    /*!
     * \brief Write stream to a FIFO.
     * \ingroup audio_blk
     *
     * \details
     * Values must be floats within [-1;1].
     * Check gr_make_wavfile_sink() for extra info.
     */
    class BLOCKS_API sennh_bat_sink_b : virtual public sync_block
    {
    public:
      // gr::blocks::wavfile_sink::sptr
      typedef boost::shared_ptr<sennh_bat_sink_b> sptr;

      /*
       * \param sample_rate Sample rate [S/s]
       */
      static sptr make(unsigned int sample_rate);

      virtual void reset() = 0;
      virtual void setcallback(void (*cbFunc)(void*, unsigned int), void *cbParam) = 0;
      virtual bool gettelegram(unsigned int *telegram) = 0;

    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_GR_SENNH_BAT_SINK_B_H */
